@@ -11,6 +11,7 @@ from httpx import Request, Response
 
 from notion_client.api_endpoints import (
     BlocksEndpoint,
+    CommentsEndpoint,
     DatabasesEndpoint,
     PagesEndpoint,
     SearchEndpoint,
@@ -48,7 +49,7 @@ class ClientOptions:
     base_url: str = "https://api.notion.com"
     log_level: int = logging.WARNING
     logger: Optional[logging.Logger] = None
-    notion_version: str = "2022-02-22"
+    notion_version: str = "2022-06-28"
 
 
 class BaseClient:
@@ -75,6 +76,7 @@ class BaseClient:
         self.users = UsersEndpoint(self)
         self.pages = PagesEndpoint(self)
         self.search = SearchEndpoint(self)
+        self.comments = CommentsEndpoint(self)
 
     @property
     def client(self) -> Union[httpx.Client, httpx.AsyncClient]:
@@ -82,12 +84,12 @@ class BaseClient:
 
     @client.setter
     def client(self, client: Union[httpx.Client, httpx.AsyncClient]) -> None:
-        client.base_url = httpx.URL(self.options.base_url + "/v1/")
+        client.base_url = httpx.URL(f"{self.options.base_url}/v1/")
         client.timeout = httpx.Timeout(timeout=self.options.timeout_ms / 1_000)
         client.headers = httpx.Headers(
             {
                 "Notion-Version": self.options.notion_version,
-                "User-Agent": "ramnes/notion-sdk-py@1.0.0",
+                "User-Agent": "ramnes/notion-sdk-py@1.0.1",
             }
         )
         if self.options.auth:
